UnpackedRemoteDisjointInductiveDataset
======================================

.. currentmodule:: pykeen.datasets.inductive

.. autoclass:: UnpackedRemoteDisjointInductiveDataset
   :show-inheritance:
